next_fire_delay

Function next_fire_delay 

fn next_fire_delay(
    now: EpochMillis,
    interval_ms: EpochMillis,
    offset: EpochMillis,
) -> Duration
Milliseconds until the next fire on this environment’s own grid.

The grid has period interval_ms and is shifted by offset. When this environment’s point in the current period has already passed, the next one is a full period later.